==> mariadb-java-client-1.5.6-sources.jar: org/mariadb/jdbc/internal/packet/dao/parameters/BigDecimalParameter.java <==
package org.mariadb.jdbc.internal.packet.dao.parameters;
/*
MariaDB Client for Java

Copyright (c) 2012-2014 Monty Program Ab.

This library is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free
Software Foundation; either version 2.1 of the License, or (at your option)
any later version.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
for more details.

You should have received a copy of the GNU Lesser General Public License along
with this library; if not, write to Monty Program Ab info@montyprogram.com.

This particular MariaDB Client for Java file is work
derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
the following copyright and notice provisions:

Copyright (c) 2009-2011, Marcus Eriksson

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

Neither the name of the driver nor the names of its contributors may not be
used to endorse or promote products derived from this software without specific
prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
OF SUCH DAMAGE.
*/

import org.mariadb.jdbc.internal.MariaDbType;
import org.mariadb.jdbc.internal.stream.PacketOutputStream;

import java.math.BigDecimal;

public class BigDecimalParameter implements ParameterHolder, Cloneable {
    private BigDecimal bigDecimal;

    public BigDecimalParameter(final BigDecimal bigDecimal) {
        this.bigDecimal = bigDecimal;
    }

    public void writeTo(final PacketOutputStream os) {
        os.write(bigDecimal.toPlainString().getBytes());
    }

    public void writeUnsafeTo(final PacketOutputStream os) {
        os.writeUnsafe(bigDecimal.toPlainString().getBytes());
    }

    public long getApproximateTextProtocolLength() {
        return bigDecimal.toPlainString().getBytes().length;
    }

    public void writeBinary(PacketOutputStream writeBuffer) {
        writeBuffer.writeStringLength(bigDecimal.toPlainString());
    }

    public MariaDbType getMariaDbType() {
        return MariaDbType.DECIMAL;
    }

    public boolean isLongData() {
        return false;
    }

    public boolean isNullData() {
        return false;
    }

    @Override
    public String toString() {
        return bigDecimal.toString();
    }
}

==> mariadb-java-client-1.5.9-sources.jar: org/mariadb/jdbc/internal/packet/dao/parameters/BigDecimalParameter.java <==
package org.mariadb.jdbc.internal.packet.dao.parameters;
/*
MariaDB Client for Java

Copyright (c) 2012-2014 Monty Program Ab.

This library is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free
Software Foundation; either version 2.1 of the License, or (at your option)
any later version.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
for more details.

You should have received a copy of the GNU Lesser General Public License along
with this library; if not, write to Monty Program Ab info@montyprogram.com.

This particular MariaDB Client for Java file is work
derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
the following copyright and notice provisions:

Copyright (c) 2009-2011, Marcus Eriksson

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

Neither the name of the driver nor the names of its contributors may not be
used to endorse or promote products derived from this software without specific
prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
OF SUCH DAMAGE.
*/

import org.mariadb.jdbc.internal.MariaDbType;
import org.mariadb.jdbc.internal.stream.PacketOutputStream;

import java.math.BigDecimal;

public class BigDecimalParameter extends NotLongDataParameter implements Cloneable {
    private BigDecimal bigDecimal;

    public BigDecimalParameter(final BigDecimal bigDecimal) {
        this.bigDecimal = bigDecimal;
    }

    public void writeTo(final PacketOutputStream os) {
        os.write(bigDecimal.toPlainString().getBytes());
    }

    public void writeUnsafeTo(final PacketOutputStream os) {
        os.writeUnsafe(bigDecimal.toPlainString().getBytes());
    }

    public long getApproximateTextProtocolLength() {
        return bigDecimal.toPlainString().getBytes().length;
    }

    public void writeBinary(PacketOutputStream writeBuffer) {
        writeBuffer.writeStringLength(bigDecimal.toPlainString());
    }

    public MariaDbType getMariaDbType() {
        return MariaDbType.DECIMAL;
    }

    @Override
    public String toString() {
        return bigDecimal.toString();
    }
}
